@@ -1,4 +1,6 @@
 """
 Systematic module for filesystem and path handling
 """
-__version__ = '2.1.1'
+
+# flake8: noqa: F401
+from .tree import Tree
